@@ -400,7 +400,7 @@ def run_external_workflow(conf, task_id, vtiger_access):
         print("external_workflow_config not found in conf")
 
 
-def trigger_set_value_task(set_value_fields, conf, rule, session_name, vtiger_access):
+def trigger_set_value_task(set_value_fields, conf, rule, session_name, vtiger_access, record_id):
     """   this function will execute revise query on vtiger for setting values
             params:
             1.set_value_fields : json object which have list of json payload of values to be set
@@ -425,7 +425,9 @@ def trigger_set_value_task(set_value_fields, conf, rule, session_name, vtiger_ac
     print("Id: {}".format(id))
     print("lead_id: {}".format(lead_id))
     final_id = id if id else lead_id
+    final_id = record_id if record_id else final_id
     print("Module {}".format(module))
+    print("final_id {}".format(final_id))
     if final_id and record_module:
         id = final_id if "x" in final_id else module + 'x' + final_id
         element = {"id": str(id)}
@@ -479,7 +481,7 @@ def trigger_set_value_task(set_value_fields, conf, rule, session_name, vtiger_ac
             return None
 
 
-def invoke_set_value_task(conf, task_id, vtiger_access):
+def invoke_set_value_task(conf, task_id, vtiger_access, record_id=None):
     """   this function will execute set value task.
             params:
             1.conf : conf object
@@ -576,7 +578,7 @@ def invoke_set_value_task(conf, task_id, vtiger_access):
                                 url = '{vtiger_url}/webservice.php?operation=query&sessionName={sessionName}&query={query}'.format(
                                     sessionName=session_name, query=query, vtiger_url=vtiger_access.get('vtiger_url'))
                                 url = url.replace("''", "' '")
-                                response, status = invoke_http_request(url, request_type, headers)
+                                response, status = invoke_http_ request(url, request_type, headers)
 
 
                                 vtiger_access['vtiger_session'] = session_name
@@ -588,12 +590,13 @@ def invoke_set_value_task(conf, task_id, vtiger_access):
                     print(response)
                     if response.get('result') and set_value_fields:
                         set_value_response = trigger_set_value_task(set_value_fields, conf, rule, session_name,
-                                                                    vtiger_access)
+                                                                    vtiger_access, record_id)
                         return set_value_response
 
             elif set_value_fields:
 
-                set_value_response = trigger_set_value_task(set_value_fields, conf, rule, session_name, vtiger_access)
+                set_value_response = trigger_set_value_task(set_value_fields, conf, rule, session_name, vtiger_access,
+                                                            record_id)
                 return set_value_response
         else:
             print("set_value_configs not found for task id:", task_id)
